Calculate lift ranked words and values for a topic
Arguments
- beta
A numeric matrix of dimension (topics x words) representing the probability distribution of words within each topic. Each row should sum to 1. Beta must be on the probability scale (not log scale).
- vocab
a character vector of vocabulary terms corresponding to the columns of beta.
- wordcounts
a numeric vector giving the total count of each word across the entire dataset.
- topic
the topic index that we want to calculate, the default is 1.
- top_n
the number of top words to return, the default is to return all words.